@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2011 Free Software Foundation
+   Copyright (C) 2000-2022 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -352,8 +353,6 @@ static PCFileManager *_mgr = nil;
       while (nil != (candidate = [candidateEnumerator nextObject]))
         {
           NSString *path = [directory stringByAppendingPathComponent: candidate];
-
-          NSLog(@"final candidate path is: %@", path);
           
           if ([manager isExecutableFileAtPath: path])
 	    {
@@ -416,6 +415,12 @@ static PCFileManager *_mgr = nil;
 	}
       panel = addFilesPanel;
       lastOpenDir = [prefs stringForKey:@"FileAddLastDirectory"];
+      if (lastOpenDir == nil)
+	{
+	  PCProject *pr = [projectManager activeProject];
+	  NSString *prPathRoot = [pr projectPath];
+	  lastOpenDir = prPathRoot;
+	}
       break;
     default:
       return nil;
