@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2010 Free Software Foundation
+   Copyright (C) 2000-2014 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -60,6 +60,11 @@ NSString
 
 @implementation PCProject
 
+- (NSString *)description
+{
+  return [NSString stringWithFormat: @"%@: %@ (%@)", [self className], projectName, projectPath];
+}
+
 // ============================================================================
 // ==== Init and free
 // ============================================================================
@@ -388,12 +393,12 @@ NSString
               forKey:@"ProjectWindow"];
   if ([projectWindow isToolbarVisible] == YES)
     {
-      [windows setObject:[NSString stringWithString:@"YES"]
+      [windows setObject:@"YES"
 	          forKey:@"ShowToolbar"];
     }
   else
     {
-      [windows setObject:[NSString stringWithString:@"NO"]
+      [windows setObject:@"NO"
                   forKey:@"ShowToolbar"];
     }
 
@@ -472,11 +477,11 @@ NSString
 - (BOOL)save
 {
   NSFileManager  *fm = [NSFileManager defaultManager];
-  int            spCount = [loadedSubprojects count];
+  NSUInteger      spCount = [loadedSubprojects count];
   int            i;
-  NSString *wrapperFile = [projectName stringByAppendingPathExtension: @"pcproj"];
+  NSString *wrapperFile;
   NSString *file = @"PC.project";
-  NSString *backup = [wrapperPath stringByAppendingPathExtension:@"backup"];
+  NSString *backup;
   NSMutableDictionary *dict = [projectDict mutableCopy];
   NSData *dictData = nil;
 
@@ -484,10 +489,12 @@ NSString
   [dict removeObjectForKey: PCWindows];
   [dict removeObjectForKey: PCLastEditing];
 
-  // initialize the wrapper...
+  // initialize the wrappers..
+  wrapperFile = [projectName stringByAppendingPathExtension: @"pcproj"];
   projectFileWrapper = [[NSFileWrapper alloc] initDirectoryWithFileWrappers: 
 						[NSMutableDictionary dictionaryWithCapacity: 3]];  
   wrapperPath = [projectPath stringByAppendingPathComponent: wrapperFile];
+  backup = [wrapperPath stringByAppendingPathExtension:@"backup"];
 
   // load subprojects...
   for (i = 0; i < spCount; i++)
@@ -973,7 +980,7 @@ NSString
 {
   if ([key isEqualToString:PCClasses])
     {
-      return [NSArray arrayWithObjects:@"m",nil];
+      return [NSArray arrayWithObjects:@"m",@"mm",nil];
     }
   else if ([key isEqualToString:PCHeaders])
     {
@@ -1047,11 +1054,11 @@ NSString
 {
   if ([type isEqualToString:@"m"] || [type isEqualToString:@"c"])
     {
-      return [NSString stringWithString:@"h"];
+      return @"h";
     }
   else if ([type isEqualToString:@"h"])
     {
-      return [NSString stringWithString:@"m"];
+      return @"m";
     }
 
   return nil;
@@ -1461,10 +1468,13 @@ NSString
 
       _editorCategory = [[_editor categoryPath] mutableCopy];
       range = [_editorCategory rangeOfString:fromFile];
-      [_editorCategory replaceCharactersInRange:range withString:toFile];
-      
-      [_editor setCategoryPath:_editorCategory];
-      [projectBrowser setPath:_editorCategory];
+      if (range.location != NSNotFound)
+	{
+	  [_editorCategory replaceCharactersInRange:range withString:toFile];
+
+	  [_editor setCategoryPath:_editorCategory];
+	  [projectBrowser setPath:_editorCategory];
+	}
       RELEASE(_editorCategory);
     }
   else
