@@ -308,11 +308,11 @@ NSString *PCBrowserDidSetPathNotification = @"PCBrowserDidSetPathNotification";
 
 - (void)reloadLastColumnAndNotify:(BOOL)yn
 {
-  int	    column = [browser lastColumn];
+  NSInteger column = [browser lastColumn];
   NSString  *category = [self nameOfSelectedCategory];
-  int       selectedColumn = [browser selectedColumn];
+  NSInteger selectedColumn = [browser selectedColumn];
   NSMatrix  *colMatrix = [browser matrixInColumn:selectedColumn];
-  int       rowCount = 0, colCount = 0, spCount = 0;
+  NSInteger rowCount = 0, colCount = 0, spCount = 0;
   PCProject *activeProject = [[project projectManager] activeProject];
   NSString  *selCellTitle = [[browser selectedCell] stringValue];
 
@@ -442,13 +442,15 @@ NSString *PCBrowserDidSetPathNotification = @"PCBrowserDidSetPathNotification";
 
   if ([self nameOfSelectedFile] != nil) 
     {
+      BOOL foundFile = NO;
       BOOL foundApp = NO;
       // PCLogInfo(self, @"{doubleClick} filePath: %@", filePath);*/
 
       workspace = [NSWorkspace sharedWorkspace];
-      foundApp = [workspace getInfoForFile:filePath 
+      foundFile = [workspace getInfoForFile:filePath 
 			    application:&appName 
 				   type:&type];
+      foundApp = foundFile && appName;
       // NSLog (@"Open file: %@ with app: %@", filePath, appName);
 
       // If 'Editor' role was set in .GNUstepExtPrefs application
@@ -527,13 +529,13 @@ NSString *PCBrowserDidSetPathNotification = @"PCBrowserDidSetPathNotification";
 @implementation PCProjectBrowser (ProjectBrowserDelegate)
 
 - (void)     browser:(NSBrowser *)sender
- createRowsForColumn:(int)column
+ createRowsForColumn:(NSInteger)column
 	    inMatrix:(NSMatrix *)matrix
 {
-  NSString  *pathToCol;
-  NSArray   *files;
-  int       i = 0;
-  int       count = 0;
+  NSString   *pathToCol;
+  NSArray    *files;
+  NSUInteger i = 0;
+  NSUInteger count = 0;
 
   if (sender != browser || !matrix || ![matrix isKindOfClass:[NSMatrix class]])
     {
@@ -599,7 +601,6 @@ NSString *PCBrowserDidSetPathNotification = @"PCBrowserDidSetPathNotification";
 {
   NSString  *categoryName = nil;
   NSString  *fileName = nil;
-  NSString  *fileExtension = nil;
   NSString  *iconName = nil;
   NSImage   *icon = nil;
   PCProject *activeProject = [[project projectManager] activeProject];
@@ -611,7 +612,6 @@ NSString *PCBrowserDidSetPathNotification = @"PCBrowserDidSetPathNotification";
 	{
 	  return icon;
 	}
-      fileExtension = [fileName pathExtension];
     }
   else
     {
