@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2010 Free Software Foundation
+   Copyright (C) 2000-2014 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -220,6 +220,11 @@
   [logOutput setSelectable:YES];
   [logOutput setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
   [logOutput setBackgroundColor:[NSColor lightGrayColor]];
+  [logOutput setSelectedTextAttributes:
+    [NSDictionary dictionaryWithObjectsAndKeys:
+      [NSColor whiteColor], NSBackgroundColorAttributeName,
+      [NSColor blackColor], NSForegroundColorAttributeName,
+      nil]];
   [[logOutput textContainer] setWidthTracksTextView:YES];
   [[logOutput textContainer] setHeightTracksTextView:YES];
   [logOutput setHorizontallyResizable:NO];
@@ -383,7 +388,7 @@
   nextEL = ELNone;
   lastIndentString = @"";
 
-  buildStatus = [NSString stringWithString:@"Building..."];
+  buildStatus = @"Building...";
   [buildStatusTarget setString:@"Build"];
   [cleanButton setEnabled:NO];
   _isBuilding = YES;
@@ -413,7 +418,7 @@
   [buildArgs addObject:@"clean"];
   [buildArgs addObjectsFromArray:[self buildArguments]];
 
-  buildStatus = [NSString stringWithString:@"Cleaning..."];
+  buildStatus = @"Cleaning...";
   [buildStatusTarget setString:@"Clean"];
   [buildButton setEnabled:NO];
   _isCleaning = YES;
@@ -526,7 +531,7 @@
     }
 
   // Check build tool path
-  if (!buildTool || ![fm fileExistsAtPath:buildTool])
+  if (!buildTool || !([fm fileExistsAtPath:buildTool] || [fm fileExistsAtPath:[buildTool stringByAppendingPathExtension: @"exe"]]))
     {
       NSRunAlertPanel(@"Project Build",
   		      @"Build tool '%@' not found. Check preferences.\n"
@@ -574,7 +579,7 @@
   stdErrorPipe = [[NSPipe alloc] init];
   stdErrorHandle = [stdErrorPipe fileHandleForReading];
 
-  [errorsCountField setStringValue:[NSString stringWithString:@""]];
+  [errorsCountField setStringValue:@""];
   errorsCount = 0;
   warningsCount = 0;
 
@@ -732,8 +737,8 @@
 - (void)updateErrorsCountField
 {
   NSString *string;
-  NSString *errorsString = [NSString stringWithString:@""];
-  NSString *warningsString = [NSString stringWithString:@""];
+  NSString *errorsString = @"";
+  NSString *warningsString = @"";
 
   if (errorsCount > 0)
     {
@@ -744,7 +749,7 @@
 	}
       else
 	{
-	  errorsString = [NSString stringWithString:@"1 error"];
+	  errorsString = @"1 error";
 	}
     }
 
@@ -757,7 +762,7 @@
 	}
       else
 	{
-	  warningsString = [NSString stringWithString:@"1 warning"];
+	  warningsString = @"1 warning";
 	}
     }
 
@@ -870,10 +875,10 @@
 // --- Parsing utilities
 - (BOOL)line:(NSString *)lineString startsWithString:(NSString *)substring
 {
-  int      position = 0;
-  NSRange  range = NSMakeRange(position,1);
+  NSInteger position = 0;
+  NSRange   range = NSMakeRange(position,1);
 
-  while ([[lineString substringFromRange:range] isEqualToString:@" "])
+  while ([[lineString substringWithRange:range] isEqualToString:@" "])
     {
       range.location = ++position;
     }
@@ -920,7 +925,7 @@
   NSString       *pathComponent;
   NSString       *path;
 
-//  NSLog(@"parseMakeLine: %@", lineString);
+  //  NSLog(@"parseMakeLine: %@", lineString);
 
   makeLineComponents = [NSMutableArray 
     arrayWithArray:[lineString componentsSeparatedByString:@" "]];
@@ -1014,7 +1019,9 @@
     {// Do current path detection
       [self parseMakeLine:string];
     }
-  else if ([self line:string startsWithString:@"gcc"])
+  else if ([self line:string startsWithString:@"gcc"] ||
+           [self line:string startsWithString:@"egcc"] ||
+           [self line:string startsWithString:@"clang"])
     {// Parse compiler output
       parsedString = [self parseCompilerLine:string];
     }
@@ -1077,11 +1084,11 @@
 - (NSArray *)parseErrorLine:(NSString *)string
 {
   NSArray             *components = [string componentsSeparatedByString:@":"];
-  NSString            *file = [NSString stringWithString:@""];
-  NSString            *includedFile = [NSString stringWithString:@""];
-  NSString            *position = [NSString stringWithString:@"{x=0; y=0}"];
-  NSString            *type = [NSString stringWithString:@""];
-  NSString            *message = [NSString stringWithString:@""];
+  NSString            *file = @"";
+  NSString            *includedFile = @"";
+  NSString            *position = @"{x=0; y=0}";
+  NSString            *type = @"";
+  NSString            *message = @"";
   NSMutableArray      *items = [NSMutableArray arrayWithCapacity:1];
   NSMutableDictionary *errorItem;
   NSString            *indentString = @"\t";
@@ -1097,13 +1104,13 @@
 		 forKey:NSUnderlineStyleAttributeName];
 
   lastEL = currentEL;
-
+  //  NSLog(@"error string: %@", string);
 /*  if (lastEL == ELFile) NSLog(@"+++ELFile");
   if (lastEL == ELFunction) NSLog(@"+++ELFunction");
   if (lastEL == ELIncluded) NSLog(@"+++ELIncluded");
   if (lastEL == ELError) NSLog(@"+++ELError");
   if (lastEL == ELNone) NSLog(@"+++ELNone");*/
-
+  //NSLog(@"components: %lu, %@", (unsigned long)[components count], components);
   if ([errorArray count] > 0)
     {
       lastFile = [[errorArray lastObject] objectForKey:@"File"];
@@ -1127,8 +1134,8 @@
     }
   else if ([components count] > 3)
     {
-      unsigned typeIndex;
-      NSString *substr;
+      NSUInteger typeIndex;
+      NSString   *substr;
 
       // file and includedFile
       file = [currentBuildPath  
@@ -1148,22 +1155,35 @@
 	}
 
       // type
+      typeIndex = NSNotFound;
       if ((typeIndex = [components indexOfObject:@" warning"]) != NSNotFound)
 	{
 	  type = [components objectAtIndex:typeIndex];
 	  warningsCount++;
 	}
+      else if ((typeIndex = [components indexOfObject:@" note"]) != NSNotFound) // generated by clang
+	{
+	  type = [components objectAtIndex:typeIndex];
+	}
       else if ((typeIndex = [components indexOfObject:@" error"]) != NSNotFound)
 	{
 	  type = [components objectAtIndex:typeIndex];
 	  errorsCount++;
 	}
+      else if ((typeIndex = [components indexOfObject:@" fatal error"]) != NSNotFound)
+	{
+	  type = [components objectAtIndex:typeIndex];
+	  errorsCount++;
+	}
+
+      //     NSLog(@"typeIndex: %u", (unsigned int)typeIndex);
       // position
       if (typeIndex == 2) // :line:
 	{
 	  int      lInt = atoi([[components objectAtIndex:1] cString]);
 	  NSNumber *lNumber = [NSNumber numberWithInt:lInt];
 
+          //          NSLog(@"type 2, parsed l: %i", lInt);
 	  position = [NSString stringWithFormat:@"{x=%i; y=0}", 
 		   [lNumber intValue]];
 	}
@@ -1174,8 +1194,9 @@
 	  NSNumber *lNumber = [NSNumber numberWithInt:lInt];
 	  NSNumber *cNumber = [NSNumber numberWithInt:cInt];
 
+          //          NSLog(@"type 3, parsed l,c: %i, %i", lInt, cInt);
 	  position = [NSString stringWithFormat:@"{x=%i; y=%i}", 
-	      	   [lNumber intValue], [cNumber floatValue]];
+	      	   [lNumber intValue], [cNumber intValue]];
 	}
       // message
       substr = [NSString stringWithFormat:@"%@:", type];
@@ -1269,7 +1290,7 @@
 }
 
 // --- Error output table delegate methods
-- (int)numberOfRowsInTableView:(NSTableView *)aTableView
+- (NSInteger)numberOfRowsInTableView:(NSTableView *)aTableView
 {
   if (errorArray != nil && aTableView == errorOutput)
     {
@@ -1281,7 +1302,7 @@
     
 - (id)            tableView:(NSTableView *)aTableView
   objectValueForTableColumn:(NSTableColumn *)aTableColumn
-                        row:(int)rowIndex
+                        row:(NSInteger)rowIndex
 {
   NSDictionary *errorItem;
 
@@ -1297,7 +1318,7 @@
 
 - (void)errorItemClick:(id)sender
 {
-  int             rowIndex = [errorOutput selectedRow];
+  NSInteger       rowIndex = [errorOutput selectedRow];
   NSDictionary    *error = [errorArray objectAtIndex:rowIndex];
   NSPoint         position;
   PCProjectEditor *projectEditor = [project projectEditor];
@@ -1308,9 +1329,10 @@
 				   windowed:NO];
   if (editor)
     {
+      // TODO / FIXME using a NSPoint here is weak since it is Float vs. integer line numbers
       position = NSPointFromString([error objectForKey:@"Position"]);
       [projectEditor orderFrontEditorForFile:[error objectForKey:@"File"]];
-      [editor scrollToLineNumber:(unsigned int)position.x];
+      [editor scrollToLineNumber:(NSUInteger)position.x];
 
 /*      NSLog(@"%i: %@(%@): %@", 
 	    position.x, 
