@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2010 Free Software Foundation
+   Copyright (C) 2000-2023 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -417,19 +417,19 @@
   
   if ([selectedTitle isEqualToString:@"Header Directories Search Order"])
     {
-      ASSIGN(searchItems, searchHeaders);
+      ASSIGN(searchItems, [NSMutableArray arrayWithArray:searchHeaders]);
     }
   else if ([selectedTitle isEqualToString:@"Library Directories Search Order"])
     {
-      ASSIGN(searchItems, searchLibs);
+      ASSIGN(searchItems, [NSMutableArray arrayWithArray:searchLibs]);
     }
   else if ([selectedTitle isEqualToString:@"Build Targets"])
     {
-      ASSIGN(searchItems,[project buildTargets]);
+      ASSIGN(searchItems,[NSMutableArray arrayWithArray:[project buildTargets]]);
     }
   else  
     {
-      ASSIGN(searchItems,nil);
+      DESTROY(searchItems);
     }
 
   [searchOrderList reloadData];
@@ -977,8 +977,18 @@
 
 - (void)fileNameDidChange:(id)sender
 {
-  if ([fileName isEqualToString:[fileNameField stringValue]])
+  NSString *newName;
+
+  newName = [fileNameField stringValue];
+  if ([fileName isEqualToString:newName])
     {
+      [fileNameField setStringValue:fileName];
+      return;
+    }
+  if ([[newName stringByTrimmingCharactersInSet:
+                [NSCharacterSet whitespaceAndNewlineCharacterSet]] length] == 0)
+    {
+      [fileNameField setStringValue:fileName];
       return;
     }
 
