@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2010 Free Software Foundation
+   Copyright (C) 2000-2021 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -380,7 +380,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 
       [[NSNotificationCenter defaultCenter]
 	postNotificationName:PCActiveProjectDidChangeNotification
-	              object:activeProject];
+		      object:activeProject];
     }
 }
 
@@ -552,7 +552,6 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString     *projectPath = nil;
   NSString     *projectFileType = nil;
   PCProject    *project = nil;
-  NSDictionary *wap = nil;
   NSString     *projectPathToSave;
 
   // Check project path for invalid characters
@@ -675,14 +674,13 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
       [self startSaveTimer];
       [project validateProjectDict];
       
-      if (!project) 
-	{
-	  return nil;
-	}
-      
       [loadedProjects setObject:project forKey:[project projectPath]];
+      [[NSDocumentController sharedDocumentController] noteNewRecentDocumentURL: [NSURL fileURLWithPath:projectPathToSave]];
+      PCLogStatus(self, @"Saved opened Document as %@", projectPathToSave);
+
       if (flag)
 	{
+          NSDictionary *wap = nil;
 	  [project setProjectManager:self];
 	  
 	  // Windows and panels
@@ -699,14 +697,18 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	    {
 	      [[project projectWindow] showProjectLoadedFiles:self];
 	    }
-	  
-	  [[project projectWindow] makeKeyAndOrderFront:self];
-	  [self setActiveProject: project];
 	}
-      PCLogStatus(self, @"Saved opened Document as %@", projectPathToSave);
-      [[NSDocumentController sharedDocumentController] noteNewRecentDocumentURL: [NSURL fileURLWithPath:projectPathToSave]];
+    }
+  else
+    {
+      PCLogStatus(self, @"Project %@ already Open", [project projectName]);
     }
 
+  if (flag)
+    {
+      [self setActiveProject: project];
+      [[project projectWindow] makeKeyAndOrderFront:self];
+    }
   
   return project;
 }
@@ -759,6 +761,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString               *className = [projectTypes objectForKey:projectType];
   PCProject<ProjectType> *projectCreator;
   PCProject              *project = nil;
+  NSString               *subType = nil;
  
   if ((project = [loadedProjects objectForKey: [aPath stringByDeletingLastPathComponent]]) != nil)
     {
@@ -766,6 +769,9 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
       return project;
     }
 
+  if ([projectType isEqualToString:@"Application"])
+    subType = PCProjectInterfaceGorm;
+ 
   projectCreator = [bundleManager objectForClassName:className 
 					  bundleType:@"project"
 					    protocol:@protocol(ProjectType)];
@@ -791,7 +797,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
     }
 
   // Create project
-  if (!(project = [projectCreator createProjectAt:aPath])) 
+  if (!(project = [projectCreator createProjectAt:aPath withOption:subType])) 
     {
       NSRunAlertPanel(@"New Project",
 		      @"Project %@ could not be created.\nReport bug, please!",
@@ -811,7 +817,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString  *filePath;
   NSString  *projectType;
   PCProject *project;
-
+  NSString  *projectPath;
 
   [self createProjectTypeAccessaryView];
   
@@ -852,7 +858,9 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 	  return;
 	}
 
-      [loadedProjects setObject:project forKey: [project projectPath]];
+      projectPath = [project projectPath];
+      [[NSDocumentController sharedDocumentController] noteNewRecentDocumentURL:[NSURL fileURLWithPath:projectPath]];
+      [loadedProjects setObject:project forKey:projectPath];
       [self setActiveProject:project];
       [[project projectWindow] orderFront:self];
     }
@@ -1116,6 +1124,7 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
 // ============================================================================
 
 - (void)openFileAtPath:(NSString *)filePath
+	      windowed:(BOOL)windowed
 {
   editorManager = [self editorManager];
 
@@ -1123,11 +1132,17 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
     {
       [editorManager openEditorForFile:filePath 
 			      editable:YES
-			      windowed:YES];
+			      windowed:windowed];
       [editorManager orderFrontEditorForFile:filePath];
     }
 }
 
+- (void)openFileAtPath:(NSString *)filePath
+{
+  [self openFileAtPath: filePath windowed: YES];
+}
+
+
 - (void)openFile
 {
   NSArray  *files = nil;
@@ -1333,6 +1348,9 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   // Create subproject
   subproject = [self createSubprojectOfType:spType path:spPath];
 
+  //  PCLogInfo(self, @"{createSubproject} add to %@", [activeProject projectName]);
+  [activeProject addSubproject:subproject];
+
   return;
 }
 
@@ -1342,11 +1360,15 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   NSString               *className = [projectTypes objectForKey:projectType];
   PCProject<ProjectType> *projectCreator;
   PCProject              *subproject = nil;
+  NSString               *subType = nil;
+
+  if ([projectType isEqualToString:@"Application"])
+    subType = PCProjectInterfaceGorm;
 
   projectCreator = [bundleManager objectForClassName:className 
 					  bundleType:@"project"
 					    protocol:@protocol(ProjectType)];
-  if (!(subproject = [projectCreator createProjectAt:aPath])) 
+  if (!(subproject = [projectCreator createProjectAt:aPath withOption:subType])) 
     {
       NSRunAlertPanel(@"New Subproject",
 		      @"Internal error!"
@@ -1358,9 +1380,6 @@ NSString *PCActiveProjectDidChangeNotification = @"PCActiveProjectDidChange";
   [subproject setSuperProject:activeProject];
   [subproject setProjectManager:self];
 
-//  PCLogInfo(self, @"{createSubproject} add to %@", [activeProject projectName]);
-  [activeProject addSubproject:subproject];
-
   return subproject;
 }
 
