@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2000-2010 Free Software Foundation
+   Copyright (C) 2000-2023 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+	    Riccardo Mottola
 
    This file is part of GNUstep.
 
@@ -259,11 +260,9 @@
 
 - (void)dealloc
 {
-#ifdef DEVELOPMENT
-  NSLog (@"PCProjectWindow: dealloc");
-#endif
-
   [[NSNotificationCenter defaultCenter] removeObserver:self];
+  [h_split setDelegate:nil];
+  [v_split setDelegate:nil];
   [projectWindow close];
 
   [super dealloc];
@@ -662,8 +661,9 @@
 
 - (void)makeKeyAndOrderFront:(id)sender
 {
-//  PCLogInfo(self, @"makeKeyAndOrderFront sender: %@", [sender className]);
-  [projectWindow makeKeyAndOrderFront:nil];
+//  PCLogInfo(self, @"makeKeyAndOrderFront % @ sender: %@", [projectWindow title], [sender className]);
+//  NSLog(@"makeKeyAndOrderFront %@ sender: %@", [projectWindow title], [sender className]);
+  [projectWindow makeKeyAndOrderFront:self];
 }
 
 - (void)makeKeyWindow
@@ -720,8 +720,6 @@
 
 /*  PCLogInfo(self, @"windowDidBecomeKey: activeSubproject %@",
 	    [[project activeSubproject] projectName]);*/
-  NSLog(@"windowDidBecomeKey: project %@",
-	[project projectName]);
 
   if ([[project projectManager] rootActiveProject] != project)
     {
@@ -808,7 +806,6 @@
       if (windowsDict != nil)
 	{
 	  browserString = [windowsDict objectForKey:@"ProjectBrowser"];
-	  NSLog(@"Browser size '%@'", browserString);
 	  if (browserString != nil && ![browserString isEqualToString:@""])
 	    {
 	      browserRect = NSRectFromString(browserString);
