@@ -1,9 +1,10 @@
 /*
 **  PCDebuggerView
 **
-**  Copyright (c) 2008
+**  Copyright (c) 2008-2021
 **
-**  Author: Gregory Casamento <greg_casamento@yahoo.com>
+**  Author: Gregory Casamento <greg.casamento@gmail.com>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -20,20 +21,26 @@
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#import "PTYView.h"
+#import <Foundation/NSString.h>
+#import <AppKit/NSTextView.h>
+
 
 @class PCDebugger;
-@class NSString;
 
-@interface PCDebuggerView : PTYView
+@interface PCDebuggerView : NSTextView
 {
   PCDebugger *debugger;
-  NSString *currentFile;
-  int subProcessId;
 }
 
 - (void) setDebugger:(PCDebugger *)theDebugger;
-- (void) setCurrentFile: (NSString *)fileName;
-- (NSString *) currentFile;
-- (int) subProcessId;
+- (void)setFont:(NSFont *)font;
+
+
+
+- (void) runProgram: (NSString *)path
+ inCurrentDirectory: (NSString *)directory
+   logStandardError: (BOOL)logError;
+
+- (void) putString: (NSString *)string;
+
 @end
