@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2002-2014 Free Software Foundation
+   Copyright (C) 2002-2021 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -37,19 +37,21 @@
 {
   id              _editorManager;
 
-  NSScrollView    *_extScrollView;
+  NSTextField     *_extStatusField;
   PCEditorView    *_extEditorView;
-  NSScrollView    *_intScrollView;
+  NSTextField     *_intStatusField;
   PCEditorView    *_intEditorView;
   NSTextStorage   *_storage;
   NSMutableString *_path;
   NSString        *_categoryPath;
   NSWindow        *_window;
+  NSView          *_containerView;
 
   BOOL            _isEdited;
   BOOL            _isEditable;
   BOOL            _isWindowed;
   BOOL            _isExternal;
+  NSDate          *_lastSaveDate;
 
   // Search
   NSView          *goToLineView;
@@ -72,21 +74,11 @@
   NSColor *highlightColor;
   NSColor *backgroundColor;
   NSColor *readOnlyColor;
-  NSColor *textBackground;
-  
-  // location of the highlit delimiter character
-  unsigned int highlitCharacterLocation;
+  NSColor *textBackgroundColor;
 
-  // is YES if we are currently highlighting a delimiter character
-  // otherwise NO
-  BOOL isCharacterHighlit;
-  int  highlited_chars[2];
-
-  // the stored color and font attributes of the highlit character, so
-  // that they can be restored later on when the character is un-highlit
-  NSColor *previousFGColor;
-  NSColor *previousBGColor;
-  NSColor *previousFont;
+  // location of the highlighted delimiter characters
+  // NSNotFound means not set
+  NSUInteger  highlighted_chars[2];
   
   // This is used to protect that -textViewDidChangeSelection: invocations
   // don't do anything when the text view changing, because this causes
@@ -94,8 +86,14 @@
   // of this method.
   BOOL editorTextViewIsPressingKey;
 
+  // Slightly delay drawing of highlit parentheses
+  NSTimer *phlTimer;
+
   // keep one undo manager for the editor
   NSUndoManager *undoManager;
+
+  // optimize line status calculations
+  NSTimer *lsTimer;
 }
 
 - (BOOL)editorShouldClose;
@@ -119,7 +117,7 @@
 - (BOOL)resignFirstResponder:(PCEditorView *)view;
 
 // ===========================================================================
-// ==== Parser and scrolling
+// ==== Parser and scrolling and Line Status
 // ===========================================================================
 
 - (void)fileStructureItemSelected:(NSString *)item;  // CodeEditor protocol
@@ -127,6 +125,9 @@
 - (void)scrollToMethodName:(NSString *)methodName;
 - (void)scrollToLineNumber:(NSUInteger)lineNumber; // CodeEditor protocol
 
+- (void)computeCurrentLineFromTimer: (NSTimer *)timer;
+- (void)computeCurrentLine: (NSTextView *)editorView;
+
 @end
 
 @interface PCEditor (UInterface)
@@ -150,7 +151,7 @@
 @interface PCEditor (Parenthesis)
 
 - (void)unhighlightCharacter: (NSTextView *)editorView;
-- (void)highlightCharacterAt:(NSUInteger)location inEditor: (NSTextView *)editorView;
+- (void)highlightCharacterPair: (NSTextView *)editorView;
 - (void)computeNewParenthesisNesting: (NSTextView *)editorView;
 
 @end
