@@ -4,7 +4,7 @@
     Interface declaration of the EditorTextView class for the
     ProjectManager application.
 
-    Copyright (C) 2005-2014 Free Software Foundation
+    Copyright (C) 2005-2021 Free Software Foundation
       Saso Kiselkov
       Riccardo Mottola
 
@@ -30,11 +30,13 @@
 @class NSColor;
 @class PCEditor;
 @class SyntaxHighlighter;
+@class NSTimer;
 
 @interface PCEditorView : NSTextView <CodeEditorView>
 {
   PCEditor          *editor;
   SyntaxHighlighter *highlighter;
+  NSTimer           *hlTimer;
 }
 
 + (NSFont *)defaultEditorFont;
@@ -42,12 +44,16 @@
 + (NSFont *)defaultEditorItalicFont;
 + (NSFont *)defaultEditorBoldItalicFont;
 
-- (void)setEditor:(PCEditor *)anEditor;
+- (NSFont *)editorFont;
+- (NSFont *)editorBoldFont;
+- (NSFont *)editorItalicFont;
+- (NSFont *)editorBoldItalicFont;
+
+
+- (void)setEditor:(NSObject <CodeEditor> *)anEditor;
 
 - (void)createSyntaxHighlighterForFileType:(NSString *)fileType;
 
-- (void)insertText:text;
-
 - (NSRect)selectionRect;
 
 // =====
