@@ -4,7 +4,7 @@
     Implementation of the PCEditorView class for the
     ProjectManager application.
 
-    Copyright (C) 2005-2014 Free Software Foundation
+    Copyright (C) 2005-2021 Free Software Foundation
       Saso Kiselkov
       Serg Stoyan
       Riccardo Mottola
@@ -40,21 +40,14 @@
 
 #import <ctype.h>
 
+#import <ProjectCenter/PCProjectManager.h>
+
 #import "PCEditor.h"
 #import "SyntaxHighlighter.h"
 #import "LineJumper.h"
+#import "Modules/Preferences/EditorFSC/PCEditorFSCPrefs.h"
 
-static inline float my_abs(float aValue)
-{
-  if (aValue >= 0)
-    {
-      return aValue;
-    }
-  else
-    {
-      return -aValue;
-    }
-}
+#define SYNTAX_HL_DELAY 0.05
 
 /**
  * Computes the indenting offset of the last line before the passed
@@ -69,7 +62,7 @@ static inline float my_abs(float aValue)
  * @return The ammount of spaces the last line containing text is offset
  *      from it's start.
  */
-static int ComputeIndentingOffset(NSString * string, unsigned int start)
+static int ComputeIndentingOffset(NSString * string, NSUInteger start)
 {
   SEL sel = @selector(characterAtIndex:);
   unichar (* charAtIndex)(NSString *, SEL, unsigned int) =
@@ -177,9 +170,9 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
 }
 
 // Go backward to first '\n' char or start of file
-- (int)lineStartIndexForIndex:(int)index forString:(NSString *)string
+- (NSInteger)lineStartIndexForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int line_start;
+  NSInteger line_start;
 
   // Get line start index moving from index backwards
   for (line_start = index;line_start > 0;line_start--)
@@ -192,15 +185,13 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
 	}
     }
 
-  NSLog(@"index: %i start: %i", index, line_start);
-
   return line_start > index ? index : line_start;
 }
 
-- (int)lineEndIndexForIndex:(int)index forString:(NSString *)string
+- (NSInteger)lineEndIndexForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int line_end;
-  int string_length = [string length];
+  NSInteger line_end;
+  NSInteger string_length = [string length];
 
   // Get line start index moving from index backwards
   for (line_end = index;line_end < string_length;line_end++)
@@ -211,30 +202,26 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
 	}
     }
 
-  NSLog(@"index: %i end: %i", index, line_end);
-
   return line_end < string_length ? line_end : string_length;
 }
 
-- (int)previousLineStartIndexForIndex:(int)index forString:(NSString *)string
+- (NSInteger)previousLineStartIndexForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int cur_line_start;
-  int prev_line_start;
+  NSInteger cur_line_start;
+  NSInteger prev_line_start;
 
   cur_line_start = [self lineStartIndexForIndex:index forString:string];
   prev_line_start = [self lineStartIndexForIndex:cur_line_start-1
  				       forString:string];
 
-  NSLog(@"index: %i prev_start: %i", index, prev_line_start);
-
   return prev_line_start;
 }
 
-- (int)nextLineStartIndexForIndex:(int)index forString:(NSString *)string
+- (NSInteger)nextLineStartIndexForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int cur_line_end;
-  int next_line_start;
-  int string_length = [string length];
+  NSInteger cur_line_end;
+  NSInteger next_line_start;
+  NSInteger string_length = [string length];
 
   cur_line_end = [self lineEndIndexForIndex:index forString:string];
   next_line_start = cur_line_end + 1;
@@ -249,12 +236,13 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
     }
 }
 
-- (unichar)firstCharOfLineForIndex:(int)index forString:(NSString *)string
+- (unichar)firstCharOfLineForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int line_start = [self lineStartIndexForIndex:index forString:string];
-  int i;
+  NSInteger line_start = [self lineStartIndexForIndex:index forString:string];
+  NSInteger i;
   unichar c;
 
+  c = 0;
   // Get leading whitespaces range
   for (i = line_start; i >= 0; i++)
     {
@@ -270,30 +258,25 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
   return c;
 }
 
-- (unichar)firstCharOfPrevLineForIndex:(int)index forString:(NSString *)string
+- (unichar)firstCharOfPrevLineForIndex:(NSInteger)index forString:(NSString *)string
 {
-  int line_start = [self previousLineStartIndexForIndex:index 
+  NSInteger line_start = [self previousLineStartIndexForIndex:index 
 						   forString:string];
 
   return [self firstCharOfLineForIndex:line_start forString:string];
 }
 
-- (unichar)firstCharOfNextLineForIndex:(int)index
-{
-  return 0;
-}
-
 - (void)performIndentation
 {
-  NSString *string = [self string];
-  int      location;
-  int      line_start;
-  int      offset;
-  unichar  c, plfc, clfc;
-  NSRange  wsRange;
+  NSString  *string = [self string];
+  NSInteger location;
+  NSInteger line_start;
+  NSInteger offset;
+  unichar   c, plfc, clfc;
+  NSRange   wsRange;
   NSMutableString *indentString;
   NSCharacterSet  *wsCharSet = [NSCharacterSet whitespaceCharacterSet];
-  int i;
+  NSInteger i;
 //  int point;
 
   location = [self selectedRange].location;
@@ -324,7 +307,7 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
       if (![wsCharSet characterIsMember:c])
 	{
 	  offset = offset - line_start;
-	  NSLog(@"offset: %i", offset);
+	  NSLog(@"offset: %li", offset);
 	  break;
 	}
     }
@@ -341,7 +324,7 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
 
   // Get offset from BOL of previous line
 //  offset = ComputeIndentingOffset([self string], line_start-1);
-  NSLog(@"Indent offset: %i", offset);
+  NSLog(@"Indent offset: %li", offset);
 
   // Replace current line whitespaces with new ones
   indentString = [[NSMutableString alloc] initWithString:@""];
@@ -374,23 +357,9 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
 
 + (NSFont *)defaultEditorFont
 {
-  NSUserDefaults *df = [NSUserDefaults standardUserDefaults];
-  NSString       *fontName;
-  float          fontSize;
   NSFont         *font = nil;
 
-  fontName = [df objectForKey:@"EditorFont"];
-  fontSize = [df floatForKey:@"EditorFontSize"];
-
-  if (fontName != nil)
-    {
-      font = [NSFont fontWithName:fontName size:fontSize];
-    }
-  if (font == nil)
-    {
-      font = [NSFont userFixedPitchFontOfSize:fontSize];
-    }
-
+  font = [NSFont userFixedPitchFontOfSize:0];
   return font;
 }
 
@@ -419,6 +388,50 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
                                                         NSItalicFontMask];
 }
 
+- (NSFont *)editorFont
+{
+  id <PCPreferences> prefs;
+  NSString          *fontName;
+  CGFloat            fontSize;
+  NSFont            *font = nil;
+
+  prefs = [[[editor editorManager] projectManager] prefController];
+
+  fontName = [prefs stringForKey:EditorTextFont];
+  fontSize = [prefs floatForKey:EditorTextFontSize];
+
+  font = [NSFont fontWithName:fontName size:fontSize];
+  if (font == nil)
+    font = [NSFont userFixedPitchFontOfSize:0]; 
+
+  return font;
+}
+
+- (NSFont *)editorBoldFont
+{
+  NSFont *font = [self editorFont];
+
+  return [[NSFontManager sharedFontManager] convertFont:font
+                                            toHaveTrait:NSBoldFontMask];
+}
+
+- (NSFont *)editorItalicFont
+{
+  NSFont *font = [self editorFont];
+
+  return [[NSFontManager sharedFontManager] convertFont:font
+                                            toHaveTrait:NSItalicFontMask];
+}
+
+- (NSFont *)editorBoldItalicFont
+{
+  NSFont *font = [self editorFont];
+
+  return [[NSFontManager sharedFontManager] convertFont:font
+                                            toHaveTrait:NSBoldFontMask |
+                                                        NSItalicFontMask];
+}
+
 // ---
 - (BOOL)becomeFirstResponder
 {
@@ -443,147 +456,90 @@ static int ComputeIndentingOffset(NSString * string, unsigned int start)
   [super dealloc];
 }
 
-- (void)setEditor:(PCEditor *)anEditor
+- (void)setEditor:(NSObject <CodeEditor> *)anEditor
 {
-  editor = anEditor;
+  editor = (PCEditor *)anEditor;
 }
 
-- (PCEditor *)editor
+- (NSObject <CodeEditor> *)editor
 {
   return editor;
 }
 
-- (void)awakeFromNib
-{
-/*  NSData * data;
-  NSUserDefaults * df = [NSUserDefaults standardUserDefaults];
-
-  drawCrosshairs = [df boolForKey: @"DrawCrosshairs"];
-  if (drawCrosshairs)
-    {
-      if ((data = [df dataForKey: @"CrosshairColor"]) == nil ||
-        (crosshairColor = [NSUnarchiver unarchiveObjectWithData: data]) == nil)
-        {
-          crosshairColor = [NSColor lightGrayColor];
-        }
-      [crosshairColor retain];
-    }
-
-  guides = [NSMutableArray new];*/
-}
-
 - (void)drawRect:(NSRect)r
 {
-  NSRange drawnRange;
-
   if (highlighter)
     {
+      NSRange drawnRange;
+      NSValue *timerInfo;
+
       drawnRange = [[self layoutManager] 
 	glyphRangeForBoundingRect:r inTextContainer:[self textContainer]];
-      [highlighter highlightRange:drawnRange];
+      drawnRange = [[self layoutManager] characterRangeForGlyphRange:drawnRange
+                                                    actualGlyphRange:NULL];
+
+      timerInfo = [NSValue valueWithRange:drawnRange];
+
+      if (nil != hlTimer)
+	{
+	  [hlTimer invalidate];
+	  hlTimer = nil;
+	}
+
+      hlTimer = [NSTimer scheduledTimerWithTimeInterval:SYNTAX_HL_DELAY
+						 target:self
+					       selector:@selector(highlightRangeFromTimer:)
+					       userInfo:timerInfo
+						repeats:NO];
     }
 
   [super drawRect:r];
 }
 
+- (void)highlightRangeFromTimer:(NSTimer *)t
+{
+  NSRange range;
+
+  range = [(NSValue *)[t userInfo] rangeValue];
+  hlTimer = nil;
+  [highlighter highlightRange:range];
+}
+
 - (void)createSyntaxHighlighterForFileType:(NSString *)fileType
 {
   ASSIGN(highlighter, 
 	 [[[SyntaxHighlighter alloc] initWithFileType:fileType
 					  textStorage:[self textStorage]]
 					  autorelease]);
+  [highlighter setNormalFont: [self editorFont]];
+  [highlighter setBoldFont: [self editorBoldFont]];
+  [highlighter setItalicFont: [self editorItalicFont]];
+  [highlighter setBoldItalicFont: [self editorBoldItalicFont]];
 }
 
-- (void)insertText:text
+- (void) cancelOperation: (id)sender
 {
-  /* NOTE: On Windows we ensure to get a string in UTF-8 encoding. The problem
-   * is the highlighter that don't use a consistent codification causing a
-   * problem on Windows platform. Anyway, the plugin for Gemas editor works
-   * better and don't show this problem.
-   */
-  if ([text isKindOfClass:[NSString class]])
-    {
-      NSString * string = text;
+  // ignore ESC char
+}
 
-      if ([text characterAtIndex:0] == 27)
-	{
-	  NSLog(@"ESC key pressed. Ignoring it");
-	  return;
-	}
+- (void) insertNewline: (id)sender
+{
+  NSInteger location = [self selectedRange].location;
+  int  offset = ComputeIndentingOffset([self string], location);
+  char buf[offset+2];
 
-      if ([string isEqualToString:@"\n"])
-        {
-/*          if ([[NSUserDefaults standardUserDefaults]
-            boolForKey:@"ReturnDoesAutoindent"])
-            {*/
-	      int  location = [self selectedRange].location;
-              int  offset = ComputeIndentingOffset([self string], location);
-              char *buf;
+  buf[0] = '\n';
+  memset(&buf[1], ' ', offset);
+  buf[offset+1] = '\0';
 
-              buf = (char *) malloc((offset + 2) * sizeof(unichar));
-	      buf[0] = '\n';
-              memset(&buf[1], ' ', offset);
-              buf[offset+1] = '\0';
+  // let's use UTF8 to be on the safe side
+  [self insertText: [NSString stringWithCString: buf
+				       encoding: NSUTF8StringEncoding]];
+}
 
-#ifdef WIN32
-              [super insertText:[NSString stringWithCString: buf
-					  encoding: NSUTF8StringEncoding]];
-#else
-	      [super insertText:[NSString stringWithCString:buf]];
-#endif
-              free(buf);
-/*            }
-          else
-            {
-              [super insertText:text];
-            }*/
-        }
-      else if ([string isEqualToString:@"\t"])
-        {
-	  [self performIndentation];
-/*          switch ([[NSUserDefaults standardUserDefaults]
-            integerForKey:@"TabConversion"])
-            {
-            case 0:  // no conversion
-              [super insertText:text];
-              break;
-            case 1:  // 2 spaces
-              [super insertText:@"  "];
-              break;
-            case 2:  // 4 spaces
-              [super insertText:@"    "];
-              break;
-            case 3:  // 8 spaces
-              [super insertText:@"        "];
-              break;
-            case 4:  // aligned to tab boundaries of 2 spaces long tabs
-              [self insertSpaceFillAlignedAtTabsOfSize:2];
-              break;
-            case 5:  // aligned to tab boundaries of 4 spaces long tabs
-              [self insertSpaceFillAlignedAtTabsOfSize:4];
-              break;
-            case 6:  // aligned to tab boundaries of 8 spaces long tabs
-              [self insertSpaceFillAlignedAtTabsOfSize:8];
-              break; 
-            }*/
-        }
-      else
-        {
-#ifdef WIN32
-	  [super insertText: [NSString stringWithCString: [text UTF8String]]];
-#else
-          [super insertText: text];
-#endif
-        }
-    }
-  else
-    {
-#ifdef WIN32
-      [super insertText: [NSString stringWithCString: [text UTF8String]]];
-#else
-      [super insertText: text];
-#endif
-    }
+- (void) insertTab: (id)sender
+{
+  [self performIndentation];
 }
 
 /* This extra change tracking is required in order to inform the document
