@@ -75,10 +75,10 @@ RangeOfWordInString(NSString * string, NSRange startRange)
   SEL sel = @selector(characterAtIndex:);
   unichar (*characterAtIndex)(id, SEL, unsigned int) = 
     (unichar (*)(id, SEL, unsigned int)) [string methodForSelector: sel];
-  int ahead, after;
-  unsigned int length = [string length];
+  NSInteger ahead, after;
+  NSUInteger length = [string length];
 
-  for (ahead = 1; ahead <= (int) startRange.location; ahead++)
+  for (ahead = 1; ahead <= (NSInteger) startRange.location; ahead++)
     {
       if (my_isspace(characterAtIndex(string,
                                       sel,
@@ -100,8 +100,8 @@ RangeOfWordInString(NSString * string, NSRange startRange)
     }
 
   {
-    unsigned int start = startRange.location - ahead,
-                 length = startRange.length + ahead + after;
+    NSUInteger start = startRange.location - ahead;
+    NSUInteger length = startRange.length + ahead + after;
 
     if (start > 0)
       {
@@ -117,30 +117,6 @@ RangeOfWordInString(NSString * string, NSRange startRange)
   }
 }
 
-static inline BOOL
-LocateString(NSString * str,
-             unichar * buf,
-             unsigned int length,
-             unsigned int offset)
-{
-  unsigned int i, n;
-
-  for (i = 0, n = [str length]; i < n; i++)
-    {
-      if (i >= length)
-        {
-          return NO;
-        }
-
-      if (buf[i + offset] != [str characterAtIndex: i])
-        {
-          return NO;
-        }
-    }
-
-  return YES;
-}
-
 @interface SyntaxHighlighter (Private)
 
 - (void) fixUpContextsInRange: (NSRange) r;
@@ -148,16 +124,16 @@ LocateString(NSString * str,
 - (void) fixUpKeywordsInRange: (NSRange) r;
 - (void) lazilyFixUpKeywordsInRange: (NSRange) r;
 
-- (void) assignGraphicalAttributesOfContext: (unsigned int) context
+- (void) assignGraphicalAttributesOfContext: (NSUInteger) context
                                     toRange: (NSRange) r;
 
-- (void) assignGraphicalAttributesOfKeyword: (unsigned int) keyword
-                                  inContext: (unsigned int) context
+- (void) assignGraphicalAttributesOfKeyword: (NSUInteger) keyword
+                                  inContext: (NSUInteger) context
                                     toRange: (NSRange) r;
 
-- (int) contextBeforeRange: (NSRange) r;
-- (int) contextAfterRange: (NSRange) r;
-- (int) contextAtEndOfRange: (NSRange) r;
+- (NSUInteger) contextBeforeRange: (NSRange) r;
+- (NSUInteger) contextAfterRange: (NSRange) r;
+- (NSUInteger) contextAtEndOfRange: (NSRange) r;
 
 - (void) beginEditingIfNeeded;
 - (void) endEditingIfNeeded;
@@ -178,9 +154,9 @@ LocateString(NSString * str,
   const char * beginningChars = [syntax contextBeginningCharacters];
   unsigned numBeginningChars = [syntax numberOfContextBeginningCharacters];
 
-  unsigned int i;
+  NSUInteger i;
   unichar * string;
-  unsigned int context;
+  NSUInteger context;
 
   string = (unichar *) malloc(r.length * sizeof(unichar));
   [[textStorage string] getCharacters: string range: r];
@@ -195,10 +171,10 @@ LocateString(NSString * str,
       // default context - look for beginning symbols
       if (context == 0)
         {
-          unsigned int j = 0;
+          NSUInteger j = 0;
           TextPattern * pattern = NULL;
           NSRange ctxtRange;
-          int l = 0;
+          NSInteger l = 0;
           TextPattern ** skips = [syntax contextSkipsForContext: 0];
           const char * skipChars = [syntax contextSkipCharactersForContext: 0];
           unsigned int numSkipChars = [syntax
@@ -285,19 +261,18 @@ LocateString(NSString * str,
       // exceptions
       else
         {
-          int l = 0;
+          NSInteger l = 0;
           TextPattern * ending = [syntax contextEndingForContext: context - 1];
           NSRange ctxtRange;
           TextPattern ** skips = [syntax contextSkipsForContext: context];
           const char * skipChars = [syntax contextSkipCharactersForContext:
             context];
-          unsigned int numSkipChars = [syntax
+          NSUInteger numSkipChars = [syntax
             numberOfContextSkipCharactersForContext: context];
 
           for (;i < r.length; i++)
             {
               unichar c = string[i];
-              unsigned int j;
 
               if (c < numSkipChars && skipChars[c])
                 {
@@ -335,7 +310,7 @@ LocateString(NSString * str,
               // add an attribute telling the context into the
               // text storage
               [textStorage addAttribute: ContextAttributeName
-                                  value: [NSNumber numberWithInt: context]
+                                  value: [NSNumber numberWithInteger: context]
                                   range: ctxtRange];
               [self assignGraphicalAttributesOfContext: context
                                                toRange: ctxtRange];
@@ -345,7 +320,7 @@ LocateString(NSString * str,
           if (ctxtRange.length > 0)
             {
               [textStorage addAttribute: ContextAttributeName
-                                  value: [NSNumber numberWithInt: 0]
+                                  value: [NSNumber numberWithInteger: 0]
                                   range: ctxtRange];
               [self assignGraphicalAttributesOfContext: context
                                                toRange: ctxtRange];
@@ -363,7 +338,7 @@ LocateString(NSString * str,
 - (void) fixUpKeywordsInRange: (NSRange) r
 {
   unichar * string;
-  unsigned int i;
+  NSUInteger i;
 
   string = malloc(r.length * sizeof(unichar));
   [[textStorage string] getCharacters: string range: r];
@@ -372,11 +347,11 @@ LocateString(NSString * str,
     {
       NSRange contextRange;
       TextPattern ** patterns;
-      int context;
+      NSInteger context;
 
       context = [[textStorage attribute: ContextAttributeName
                                 atIndex: i + r.location
-                         effectiveRange: &contextRange] intValue];
+                         effectiveRange: &contextRange] integerValue];
 
       contextRange = NSIntersectionRange(r, contextRange);
       contextRange.location -= r.location;
@@ -386,8 +361,8 @@ LocateString(NSString * str,
       while (i < NSMaxRange(contextRange))
         {
           unichar c = string[i];
-          unsigned int l = 0;
-          unsigned int j;
+          NSUInteger l = 0;
+          NSUInteger j;
           TextPattern * pattern;
 
           // skip whitespace - it can't start a keyword
@@ -431,7 +406,7 @@ LocateString(NSString * str,
 
 - (void) lazilyFixUpKeywordsInRange: (NSRange) r
 {
-  unsigned int i;
+  NSUInteger i;
   BOOL localDidBeginEditing = NO;
 
   for (i = r.location; i < NSMaxRange(r);)
@@ -469,7 +444,7 @@ LocateString(NSString * str,
     }
 }
 
-- (void) assignGraphicalAttributesOfContext: (unsigned int) ctxt
+- (void) assignGraphicalAttributesOfContext: (NSUInteger) ctxt
                                     toRange: (NSRange) r
 {
   BOOL bold, italic;
@@ -527,8 +502,8 @@ LocateString(NSString * str,
     }
 }
 
-- (void) assignGraphicalAttributesOfKeyword: (unsigned int) keyword
-                                  inContext: (unsigned int) context
+- (void) assignGraphicalAttributesOfKeyword: (NSUInteger) keyword
+                                  inContext: (NSUInteger) context
                                     toRange: (NSRange) r
 {
   BOOL bold, italic;
@@ -610,7 +585,7 @@ LocateString(NSString * str,
     }
 }
 
-- (int) contextBeforeRange: (NSRange) r
+- (NSUInteger) contextBeforeRange: (NSRange) r
 {
   NSRange tmp;
 
@@ -626,10 +601,11 @@ LocateString(NSString * str,
     }
 }
 
-- (int) contextAfterRange: (NSRange) r
+- (NSUInteger) contextAfterRange: (NSRange) r
 {
   NSRange tmp;
-  unsigned int i, length;
+  NSUInteger i;
+  NSUInteger length;
 
   i = NSMaxRange(r);
   length = [textStorage length];
@@ -650,10 +626,10 @@ LocateString(NSString * str,
     }
 }
 
-- (int) contextAtEndOfRange: (NSRange) r
+- (NSUInteger) contextAtEndOfRange: (NSRange) r
 {
   NSRange tmp;
-  int i = (int) NSMaxRange(r) - 1;
+  NSInteger i = (int) NSMaxRange(r) - 1;
 
   if (i < 0)
     {
@@ -663,7 +639,7 @@ LocateString(NSString * str,
     {
       return [[textStorage attribute: ContextAttributeName
                              atIndex: i
-                      effectiveRange: &tmp] intValue];
+                      effectiveRange: &tmp] integerValue];
     }
 }
 
@@ -732,6 +708,27 @@ LocateString(NSString * str,
     }
 }
 
+- (void)setNormalFont:(NSFont *)f
+{
+  ASSIGN(normalFont, f);
+}
+
+- (void)setBoldFont:(NSFont *)f
+{
+  ASSIGN(boldFont, f);
+}
+
+- (void)setItalicFont:(NSFont *)f
+{
+  ASSIGN(italicFont, f);
+}
+
+- (void)setBoldItalicFont:(NSFont *)f
+{
+  ASSIGN(boldItalicFont, f);
+}
+
+
 - (void) dealloc
 {
   NSDebugLLog(@"SyntaxHighlighter", @"SyntaxHighlighter: dealloc");
@@ -797,7 +794,6 @@ LocateString(NSString * str,
   // need to fixup contexts?
   if (NSMaxRange(r) > lastProcessedContextIndex)
     {
-      unsigned int prevContext;
       NSRange fixupRange;
 
       fixupRange = NSMakeRange(lastProcessedContextIndex,
