@@ -1,7 +1,7 @@
 /*
 **  ObjCClassHandler.m
 **
-**  Copyright (c) 2003
+**  Copyright (c) 2003-2016 The Free Software Foundation
 **
 **  Author: Yen-Ju  <yjchenx@hotmail.com>
 **
@@ -49,7 +49,6 @@
 
 - (void)dealloc
 {
-  NSLog(@"ClassHandler: dealloc");
   RELEASE(keyword);
   RELEASE(class);
   RELEASE(classes);
@@ -63,7 +62,7 @@
 
 - (void)addClassToArray
 {
-//  NSLog(@"OCCH: class: %@", class);
+  NSLog(@"OCCH: class: %@", class);
   if ([class length])
     {
       NSDictionary *dict;
@@ -173,8 +172,11 @@
 
   [super spaceAndNewLine:element];
 
-  if ((element == 0x0A) || (element == 0x0D))
+  if ((element == 0x0A) || (element == 0x0D) || (element == 0x04))
     {
+//      NSLog(@"Newline");
+//      if(element == 0x04)
+//	NSLog(@"and EOF");
       newline = YES;
     }
 
@@ -196,10 +198,8 @@
 	  else*/
 	  if ((newline || element == ' ') && (step == ClassSymbol))
     	    {
-//	      NSLog(@"keyword: %@", keyword);
 	      if ([keyword isEqualToString:@"end"])
 		{
-//		  NSLog(@"@end reached");
 		  [self addClassToArray];
 		  step = ClassNone;
 		}
