@@ -1,9 +1,10 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001 Free Software Foundation
+   Copyright (C) 2001-2021 Free Software Foundation
 
    Author: Serg Stoyan <stoyan@on.com.ua>
+           Riccardo Mottola <rm@gnu.org>
 
    This file is part of GNUstep.
 
@@ -94,7 +95,7 @@ cleanup(NSMutableDictionary *m, NSString *k)
   // Help text view
   [helpText setDrawsBackground:NO];
   [helpText setTextColor:[NSColor darkGrayColor]];
-  [helpText setFont:[NSFont systemFontOfSize:11.0]];
+  [helpText setFont:[NSFont systemFontOfSize:10.0]];
   [helpText setText:@"Click on the field and drop file in the box above"];
 
   // Document types buttons
@@ -133,7 +134,7 @@ cleanup(NSMutableDictionary *m, NSString *k)
 // --- Actions
 // ----------------------------------------------------------------------------
 
-- (void)setAppType:(id)sender
+- (IBAction)setAppType:(id)sender
 {
   NSString       *appType = [appTypeField stringValue];
   NSMutableArray *libs = [[projectDict objectForKey:PCLibraries] mutableCopy];
@@ -152,13 +153,20 @@ cleanup(NSMutableDictionary *m, NSString *k)
   [self setProjectDictObject:appType forKey:PCAppType notify:YES];
 }
 
-- (void)setAppClass:(id)sender
+- (IBAction)setAppClass:(id)sender
 {
   [self setProjectDictObject:[appClassField stringValue]
                       forKey:PCPrincipalClass
 		      notify:YES];
 }
 
+- (IBAction)setBundleIdentifier:(id)sender
+{
+  [self setProjectDictObject:[bundleIdentifierField stringValue]
+                      forKey:PCBundleIdentifier
+		      notify:YES];
+}
+
 // Application Icon
 - (void)clearAppIcon:(id)sender
 {
@@ -212,6 +220,13 @@ cleanup(NSMutableDictionary *m, NSString *k)
   [self setProjectDictObject:@"" forKey:PCHelpFile notify:YES];
 }
 
+- (IBAction)setHelpFile:(id)sender
+{
+  [self setProjectDictObject:[helpFileField stringValue]
+                      forKey:PCHelpFile
+		      notify:YES];
+}
+
 // Main Interface File
 - (void)clearMainNib: (id)sender
 {
@@ -254,7 +269,7 @@ cleanup(NSMutableDictionary *m, NSString *k)
   [docTypesPanel makeKeyAndOrderFront: nil];
 }
 
-- (void)setDocBasedApp: (id)sender
+- (IBAction)setDocBasedApp: (id)sender
 {
   NSString *docBased = [projectDict objectForKey: PCDocumentBasedApp];
 
@@ -334,11 +349,11 @@ cleanup(NSMutableDictionary *m, NSString *k)
     }
 }
 
-- (void)addDocType: (id)sender
+- (IBAction)addDocType: (id)sender
 {
-  int                 row;
+  NSInteger           row;
   NSMutableDictionary *entry = [NSMutableDictionary dictionaryWithCapacity: 6];
-  int                 selectedRow = [docTypesList selectedRow];
+  NSInteger           selectedRow = [docTypesList selectedRow];
 
   setOrRemove(entry, [docTypeField stringValue], @"NSName");
   setOrRemove(entry, [docNameField stringValue], @"NSHumanReadableName");
@@ -368,7 +383,7 @@ cleanup(NSMutableDictionary *m, NSString *k)
 		      notify: YES];
 }
 
-- (void)removeDocType: (id)sender
+- (IBAction)removeDocType: (id)sender
 {
   int selectedRow = [docTypesList selectedRow];
 
@@ -448,14 +463,14 @@ cleanup(NSMutableDictionary *m, NSString *k)
 // --- Document Types browser
 // ----------------------------------------------------------------------------
 
-- (int)numberOfRowsInTableView: (NSTableView *)aTableView
+- (NSInteger)numberOfRowsInTableView: (NSTableView *)aTableView
 {
   return [docTypesItems count];
 }
     
 - (id)            tableView: (NSTableView *)aTableView
   objectValueForTableColumn: (NSTableColumn *)aTableColumn
-                        row: (int)rowIndex
+                        row: (NSInteger)rowIndex
 {
   NSDictionary *object = nil;
 
@@ -480,11 +495,11 @@ cleanup(NSMutableDictionary *m, NSString *k)
 - (void)tableView: (NSTableView *)aTableView
    setObjectValue: anObject
    forTableColumn: (NSTableColumn *)aTableColumn
-              row: (int)rowIndex
+              row: (NSInteger)rowIndex
 {
   NSMutableDictionary *type = nil;
   
-  if (docTypesItems == nil || [docTypesItems count] <= 0)
+  if (docTypesItems == nil || [docTypesItems count] == 0)
     {
       return;
     }
@@ -504,18 +519,18 @@ cleanup(NSMutableDictionary *m, NSString *k)
 		      notify: YES];
 }
 
-- (BOOL)tableView: (NSTableView *)aTableView shouldSelectRow: (int)rowIndex
+- (BOOL)tableView: (NSTableView *)aTableView shouldSelectRow: (NSInteger)rowIndex
 {
   [self fillFieldsForRow: rowIndex];
   return YES;
 }
 
-- (void)fillFieldsForRow: (int)rowIndex
+- (void)fillFieldsForRow: (NSInteger)rowIndex
 {
   NSMutableDictionary *type = nil;
-  int          itemCount = [docTypesItems count];
+  NSUInteger      itemCount = [docTypesItems count];
 
-  if (itemCount <= 0 || rowIndex > itemCount || rowIndex < 0)
+  if (itemCount == 0 || rowIndex > itemCount || rowIndex < 0)
     {
       [docTypeField setStringValue: @""];
       [docNameField setStringValue: @""];
@@ -556,6 +571,7 @@ cleanup(NSMutableDictionary *m, NSString *k)
   // Project Attributes view
   [appTypeField selectItemWithTitle:[projectDict objectForKey:PCAppType]];
   [appClassField setStringValue:[projectDict objectForKey: PCPrincipalClass]];
+  [bundleIdentifierField setStringValue:[projectDict objectForKey: PCBundleIdentifier]];
 
   [appImageField setStringValue:[projectDict objectForKey:PCAppIcon]];
   [helpFileField setStringValue:[projectDict objectForKey:PCHelpFile]];
