@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2012 Free Software Foundation
+   Copyright (C) 2001-2022 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
@@ -141,7 +141,7 @@
 // --- ProjectType protocol
 // ----------------------------------------------------------------------------
 
-- (PCProject *)createProjectAt:(NSString *)path
+- (PCProject *)createProjectAt:(NSString *)path withOption:(NSString *)projOption
 {
   PCFileManager  *pcfm = [PCFileManager defaultManager];
   PCFileCreator  *pcfc = [PCFileCreator sharedCreator];
@@ -151,6 +151,7 @@
   NSBundle       *projBundle = [NSBundle bundleForClass:[self class]];
   NSString       *mainNibFile = nil;
   NSMutableArray *_array = nil;
+  NSString       *helpFile = nil;
 
   NSAssert(path,@"No valid project path provided!");
 
@@ -203,40 +204,57 @@
   // into English.lproj and copied into all available .lproj subdirs.
   _resourcePath = [path stringByAppendingPathComponent:@"Resources"];
 
-  // Main NIB
-  _file = [projBundle pathForResource:@"Main" ofType:@"gorm"];
-  mainNibFile = [NSString stringWithFormat:@"%@.gorm", projectName];
-  mainNibFile = [_resourcePath stringByAppendingPathComponent:mainNibFile];
-  [pcfm copyFile:_file toFile:mainNibFile];
+  if ([projOption isEqualToString: PCProjectInterfaceGorm])
+    {
+      // Main NIB (Gorm)
+      _file = [projBundle pathForResource:@"Main" ofType:@"gorm"];
+      mainNibFile = [NSString stringWithFormat:@"%@.gorm", projectName];
+      mainNibFile = [_resourcePath stringByAppendingPathComponent:mainNibFile];
+      [pcfm copyFile:_file toFile:mainNibFile];
+        
+      [projectDict setObject:[mainNibFile lastPathComponent]
+                      forKey:PCMainInterfaceFile];
+      [projectDict setObject:[NSArray arrayWithObjects:[mainNibFile lastPathComponent], nil] 
+                      forKey:PCInterfaces];
+    }
+  else if ([projOption isEqualToString: PCProjectInterfaceRenaissance])
+    {
+      // Renaissance
+      _file = [projBundle pathForResource:@"Main" ofType:@"gsmarkup"];
+      _2file = [_resourcePath stringByAppendingPathComponent:@"Main.gsmarkup"];
+      [pcfm copyFile:_file toFile:_2file];
+      _file = [projBundle pathForResource:@"MainMenu-GNUstep" ofType:@"gsmarkup"];
+      _2file = [_resourcePath 
+                 stringByAppendingPathComponent:@"MainMenu-GNUstep.gsmarkup"];
+      [pcfm copyFile:_file toFile:_2file];
+      _file = [projBundle pathForResource:@"MainMenu-OSX" ofType:@"gsmarkup"];
+      _2file = [_resourcePath 
+                 stringByAppendingPathComponent:@"MainMenu-OSX.gsmarkup"];
+      [pcfm copyFile:_file toFile:_2file];
 
-  [projectDict setObject:[mainNibFile lastPathComponent]
-                  forKey:PCMainInterfaceFile];
+      [projectDict setObject:[NSArray arrayWithObjects:@"Main.gsmarkup", @"MainMenu-GNUstep.gsmarkup", @"MainMenu-OSX.gsmarkup", nil]
+                      forKey:PCInterfaces];
+    }
 
-  // Renaissance
-  _file = [projBundle pathForResource:@"Main" ofType:@"gsmarkup"];
-  _2file = [_resourcePath stringByAppendingPathComponent:@"Main.gsmarkup"];
-  [pcfm copyFile:_file toFile:_2file];
-  _file = [projBundle pathForResource:@"MainMenu-GNUstep" ofType:@"gsmarkup"];
-  _2file = [_resourcePath 
-    stringByAppendingPathComponent:@"MainMenu-GNUstep.gsmarkup"];
-  [pcfm copyFile:_file toFile:_2file];
-  _file = [projBundle pathForResource:@"MainMenu-OSX" ofType:@"gsmarkup"];
-  _2file = [_resourcePath 
-    stringByAppendingPathComponent:@"MainMenu-OSX.gsmarkup"];
-  [pcfm copyFile:_file toFile:_2file];
-
-  [projectDict setObject:[NSArray arrayWithObjects:[mainNibFile lastPathComponent], @"Main.gsmarkup", @"MainMenu-GNUstep.gsmarkup", @"MainMenu-OSX.gsmarkup", nil] 
-    forKey:PCInterfaces];
-
-  // Info-gnutstep.plist
+  // Info-gnustep.plist
   _file = [projBundle pathForResource:@"Info" ofType:@"gnustep"];
   infoDict = [[NSMutableDictionary alloc] initWithContentsOfFile:_file];
   [infoDict setObject:projectName forKey:@"ApplicationName"];
   [infoDict setObject:projectName forKey:@"NSExecutable"];
-  [infoDict setObject:[mainNibFile lastPathComponent] 
-    forKey:@"NSMainNibFile"];
+  if (mainNibFile)
+    [infoDict setObject:[mainNibFile lastPathComponent] 
+                 forKey:@"NSMainNibFile"];
   [infoDict setObject:[projectDict objectForKey:PCPrincipalClass]
     forKey:@"NSPrincipalClass"];
+  
+  // most probably empty
+  if ([projectDict objectForKey:PCBundleIdentifier])
+    [infoDict setObject:[projectDict objectForKey:PCBundleIdentifier] forKey:@"CFBundleIdentifier"];
+
+  // Help file if present
+  helpFile = [projectDict objectForKey:@"GSHelpContentsFile"];
+  if (helpFile)
+    [infoDict setObject:helpFile forKey:@"GSHelpContentsFile"];
 
   // Write to ProjectNameInfo.plist
   _file = [NSString stringWithFormat:@"%@Info.plist",projectName];
@@ -410,6 +428,7 @@
   [self writeInfoEntry:@"ApplicationIcon" forKey:PCAppIcon];
   [self writeInfoEntry:@"ApplicationName" forKey:PCProjectName];
   [self writeInfoEntry:@"ApplicationRelease" forKey:PCRelease];
+  [self writeInfoEntry:@"CFBundleIdentifier" forKey:PCBundleIdentifier];
   [self writeInfoEntry:@"Authors" forKey:PCAuthors];
   [self writeInfoEntry:@"Copyright" forKey:PCCopyright];
   [self writeInfoEntry:@"CopyrightDescription" forKey:PCCopyrightDescription];
@@ -427,6 +446,7 @@
       [infoDict removeObjectForKey:@"NSMainNibFile"];
     }
   [self writeInfoEntry:@"NSPrincipalClass" forKey:PCPrincipalClass];
+  [self writeInfoEntry:@"GSHelpContentsFile" forKey:PCHelpFile];
   [infoDict setObject:@"Application" forKey:@"NSRole"];
   [self writeInfoEntry:@"NSTypes" forKey:PCDocumentTypes];
   [self writeInfoEntry:@"URL" forKey:PCURL];
