@@ -1,10 +1,11 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2004 Free Software Foundation
+   Copyright (C) 2001-2017 Free Software Foundation
 
    Authors: Philippe C.D. Robert
             Serg Stoyan
+            Riccardo Mottola
 	    
    Description: This is the project type 'Tool' for GNUstep. You never should 
                 create it yourself but use PCToolProj for doing this. Otherwise
@@ -54,7 +55,7 @@
 - (void)loadInfoFile;
 - (void)dealloc;
 
-- (PCProject *)createProjectAt:(NSString *)path;
+- (PCProject *)createProjectAt:(NSString *)path withOption:(NSString *)option;
 
 @end
 
