@@ -29,8 +29,6 @@
 #import "PCInfoController.h"
 #import "PCPrefController.h"
 
-#import "TextFinder.h"
-
 @implementation PCMenuController
 
 - (id)init
@@ -108,7 +106,7 @@
 
 - (void)projectNew:(id)sender
 {
-  [projectManager newProject];
+  [projectManager newProject: sender];
 }
 
 - (void)projectSave:(id)sender
@@ -207,39 +205,6 @@
 		  @"OK",nil,nil);
 }
 
-// Edit
-- (void)findShowPanel:(id)sender
-{
-  [[TextFinder sharedInstance] orderFrontFindPanel:self];
-}
-
-- (void)findNext:(id)sender
-{
-  [[TextFinder sharedInstance] findNext:self];
-}
-
-- (void)findPrevious:(id)sender
-{
-  [[TextFinder sharedInstance] findPrevious:self];
-}
-
-- (void)findJumpToSelection:(id)sender
-{
-  [[TextFinder sharedInstance] jumpToSelection:self];
-}
-
-- (void)findEnterSelection:(id)sender
-{
-  [[TextFinder sharedInstance] enterSelection:self];
-}
-
-- (void)goToLine:sender
-{
-// TODO: What is the best: inline editor popup or separate panel?
-//  [[[[projectManager rootActiveProject] projectEditor] activeEditor] 
-//    goToLine:sender];
-}
-
 // Tools
 - (void)toggleToolbar:(id)sender
 {
@@ -465,20 +430,6 @@
       if ([[menuItem title] isEqualToString:@"Rename"]) return NO;
     }
 
-  // Find menu items
-/*  if (editorIsActive == NO && [menuTitle isEqualToString: @"Find"])
-    {
-      if (![[[PCTextFinder sharedFinder] findPanel] isVisible])
-	{
-	  if ([[menuItem title] isEqualToString:@"Find Next"]) return NO;
-	  if ([[menuItem title] isEqualToString:@"Find Previous"]) return NO;
-	}
-      if ([[menuItem title] isEqualToString:@"Enter Selection"]) return NO;
-      if ([[menuItem title] isEqualToString:@"Jump to Selection"]) return NO;
-      if ([[menuItem title] isEqualToString:@"Line Number..."]) return NO;
-      if ([[menuItem title] isEqualToString:@"Man Page"]) return NO;
-    }*/
-
   // Toolbar
   if ([[menuItem title] isEqualToString:@"Hide Tool Bar"]
       && ![[[projectManager activeProject] projectWindow] isToolbarVisible])
