@@ -1,7 +1,7 @@
 /*
    GNUstep ProjectCenter - http://www.gnustep.org/experience/ProjectCenter.html
 
-   Copyright (C) 2001-2008 Free Software Foundation
+   Copyright (C) 2001-2015 Free Software Foundation
 
    This file is part of GNUstep.
 
@@ -29,6 +29,7 @@
 
 @implementation PCPrefController
 
+
 // ===========================================================================
 // ==== Class methods
 // ===========================================================================
@@ -72,7 +73,63 @@ static PCPrefController *_prefCtrllr = nil;
 {
 }
 
-// Accessory
+// ----------------------------------------------------------------------------
+// --- color utility method
+// ----------------------------------------------------------------------------
+- (NSColor *)colorFromString:(NSString *)colorString
+{
+  NSArray  *colorComponents;
+  NSString *colorSpaceName;
+  NSColor  *color;
+
+  colorComponents = [colorString componentsSeparatedByString:@" "];
+  colorSpaceName = [colorComponents objectAtIndex:0];
+
+  if ([colorSpaceName isEqualToString:@"White"]) // Treat as WhiteColorSpace
+    {
+      color = [NSColor 
+	colorWithCalibratedWhite:[[colorComponents objectAtIndex:1] floatValue]
+       			   alpha:1.0];
+    }
+  else // Treat as RGBColorSpace
+    {
+      color = [NSColor 
+	colorWithCalibratedRed:[[colorComponents objectAtIndex:1] floatValue]
+			 green:[[colorComponents objectAtIndex:2] floatValue]
+			  blue:[[colorComponents objectAtIndex:3] floatValue]
+			 alpha:1.0];
+    }
+
+  return color;
+}
+
+- (NSString *)stringFromColor:(NSColor *)color
+{
+  NSString *colorString;
+
+  colorString = nil;
+  if ([[color colorSpaceName] isEqualToString:NSCalibratedWhiteColorSpace])
+    {
+      colorString = [NSString stringWithFormat:@"White %0.1f", 
+		  [color whiteComponent]];
+    }
+  else
+    {
+      if (![[color colorSpaceName] isEqualToString:NSCalibratedRGBColorSpace])
+	color = [color colorUsingColorSpaceName:NSCalibratedRGBColorSpace];
+      colorString = [NSString stringWithFormat:@"RGB %0.1f %0.1f %0.1f",
+			      [color redComponent], 
+			      [color greenComponent],
+			      [color blueComponent]];
+    }
+
+  return colorString;
+}
+
+// ----------------------------------------------------------------------------
+// --- Accessors
+// ----------------------------------------------------------------------------
+
 - (NSString *)stringForKey:(NSString *)key
 {
   return [self stringForKey:key defaultValue:nil];
@@ -142,6 +199,33 @@ static PCPrefController *_prefCtrllr = nil;
     }
 }
 
+- (NSColor *)colorForKey:(NSString *)key
+{
+  return [self colorForKey:key defaultValue:nil];
+}
+
+- (NSColor *)colorForKey:(NSString *)key
+	    defaultValue:(NSColor *)defaultValue
+{
+  NSString *stringValue = [[NSUserDefaults standardUserDefaults]
+			    objectForKey:key];
+
+  if (stringValue)
+    {
+      NSColor *color;
+
+      color = [self colorFromString:stringValue];
+      return color;
+    }
+  else if (defaultValue)
+    {
+      [self setColor:defaultValue forKey:key notify:NO];
+      return defaultValue;
+    }
+
+  return defaultValue; // returns nil
+}
+
 - (void)setString:(NSString *)stringValue 
 	   forKey:(NSString *)aKey
 	   notify:(BOOL)notify
@@ -191,6 +275,24 @@ static PCPrefController *_prefCtrllr = nil;
     }
 }
 
+- (void)setColor:(NSColor *)color 
+	   forKey:(NSString *)aKey
+	   notify:(BOOL)notify
+{
+  NSString *stringValue;
+
+  stringValue = [self stringFromColor:color];
+  [[NSUserDefaults standardUserDefaults] setObject:stringValue
+					    forKey:aKey];
+
+  if (notify)
+    {
+      [[NSNotificationCenter defaultCenter] 
+	postNotificationName:PCPreferencesDidChangeNotification
+		      object:self];
+    }
+}
+
 - (void)loadPrefsSections
 {
   PCBundleManager    *bundleManager = [[PCBundleManager alloc] init];
